km3pipe\.dataclasses\.EventInfo
===============================

.. currentmodule:: km3pipe.dataclasses

.. autoclass:: EventInfo

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~EventInfo.__init__
      ~EventInfo.conv_from
      ~EventInfo.conv_to
      ~EventInfo.deserialise
      ~EventInfo.from_row
      ~EventInfo.serialise
   
   

   
   
   